@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['thread_3174',['Thread',['../a00598.html',1,'salhelper::Thread'],['../a00898.html',1,'osl::Thread']]],
+  ['thread_3174',['Thread',['../a00898.html',1,'osl::Thread'],['../a00598.html',1,'salhelper::Thread']]],
   ['threaddata_3175',['ThreadData',['../a00902.html',1,'osl']]],
   ['timedout_3176',['timedout',['../a00566.html',1,'salhelper::ConditionWaiter']]],
   ['timer_3177',['Timer',['../a00606.html',1,'salhelper']]],
